BaseMatcher

Struct BaseMatcher 

pub struct BaseMatcher {
    pub locally_generated: Option<bool>,
    pub bound_device: Option<BoundInterface>,
    pub mark_1: Option<Mark>,
    pub mark_2: Option<Mark>,
    /* private fields */
}
The common matcher that can be matched to both IPv4 and IPv6 packets.

A matcher matches a packet if all of the present fields match the corresponding properties.

Fields

locally_generated: Option<bool>

Matches the packet iff the packet was locally generated.

bound_device: Option<BoundInterface>

Matches on the originating interface of the outgoing packet.

mark_1: Option<Mark>

Matches the MARK_1 domain.

mark_2: Option<Mark>

Matches for the MARK_2 domain.