InstalledRuleV6

Struct InstalledRuleV6 

pub struct InstalledRuleV6 {
    pub rule_set_priority: u32,
    pub rule_index: u32,
    pub matcher: RuleMatcherV6,
    pub action: RuleAction,
}
An installed IPv6 routing rule.

Fields

rule_set_priority: u32

Rule sets are ordered by the rule set priority, rule sets are disjoint and don’t have interleaving rules among them.

rule_index: u32

Rules within a rule set are locally ordered, together with the rule set priority, this defines a global order for all installed rules.

matcher: RuleMatcherV6

The matcher part of the rule, the rule is a no-op if the matcher does not match the packet.

action: RuleAction

The action part of the rule that describes what to do if the matcher matches the packet.